/*
****************************************************************************
****************************************************************************
**                                                                        **
**                XXXX     X    X         X XXXXXX X                      **
**               X    X   X X   X    X    X X      X   X                  **
**               X       X   X  X   X X   X X      X  X                   **
**               X   XX XXXXXXX X  X   X  X XXXX   X X                    **
**               X    X X     X X X     X X X      XX                     **
**               X    X X     X XX       XX X      X                      **
**                XXXX  X     X X         X XXXXXX XXXXXX                 **
**                                                                        **
**                                                                        **
**                       Copyright (C) A. P. H.                           **
**                           BIALYSTOK 2019                               **
**                                                                        **
**                        MODULE UART1 example                            **
**                                                                        **
**                     Mikrokontroler ARM: LPC2366                        **
**                                                                        **
**                     Wersja z dnia : 2019.01.20                         **
**                     Napisal : Andrzej Pawluczuk                        **
**                                                                        **
****************************************************************************
****************************************************************************
*/

#include <LPC23xx.H>
#include "system.h"
#include "types.h"
#include "irqvectors.h"
#include "serialconst.h"
#include "uart1.h"

#define IRQCallCntLimit                 500

static ULONG IRQCallCounter ;

static void SoftwareInit ( void )
{
  /*-------------------------------------------------------------------------*/
  IRQCallCounter = 0 ;
} /* SoftwareInit */


static __irq void T1_IRQHandler ( void )
{
  /*-------------------------------------------------------------------------*/
  IRQCallCounter ++ ;
  if ( IRQCallCounter >= IRQCallCntLimit )
  {
    IRQCallCounter = 0 ;
  } /* if */ ;
  T1IR = 1 ;
  VICVectAddr = 0 ;
} /* T1_IRQHandler */


static void HardwareInit ( void ) 
{
  /*-------------------------------------------------------------------------*/
  PINSEL10 = 0 ;
  T1MR0 = ( PCLK / 1000 ) - 1 ;
  T1MCR = 3 ;
  T1TCR = 1 ;
  VICVectAddr5 = ( unsigned long ) T1_IRQHandler ;
  VICVectCntl5 = 15 ;
  VICIntEnable = ( 1 << TIMER1_Interrupt ) ;
  UART1InitEnvir ( ) ;
} /* HardwareInit */


UCHAR Hello1 [ ]      = "\r\nWitaj koles przy kompie\r\n\r\n" ;
UCHAR Hello2 [ ]      = "a,A - wlacza linie RTS\r\nb,B - wylacza linie RTS\r\nc,C - wlacza linie DTR\r\nd,D - wylacza linie DTR\r\n? - zapytanie o stan linii wyjsciowych\r\n! - help\r\n\r\n" ;


static void HelloMessage ( void )
{
  /*-------------------------------------------------------------------------*/
  UART1SendString ( Hello1 ) ;
  UART1SendString ( Hello2 ) ;
} /* HelloMessage */


static UCHAR Prompt [ ]    = "Aktualne linie wyjsciowe: " ;
static UCHAR RTSTxt [ ]    = "<RTS>" ;
static UCHAR DTRTxt [ ]    = "<DTR>" ;
static UCHAR Info01 [ ]    = "Ustawiono RTS\r\n" ;
static UCHAR Info02 [ ]    = "Skasowano RTS\r\n" ;
static UCHAR Info03 [ ]    = "Ustawiono DTR\r\n" ;
static UCHAR Info04 [ ]    = "Skasowano DTR\r\n" ;

void ProcessChar ( UCHAR Ch )
{
  UCHAR ModemStatus ;
  /*-------------------------------------------------------------------------*/
  if ( ( Ch == 'a' ) || ( Ch == 'A' ) )
  {
    UART1SendString ( Info01 ) ;
    SetOutputModemLine ( RTSControlUARTCode ) ;
  } /* if */ ;
  if ( ( Ch == 'b' ) || ( Ch == 'B' ) )
  {
    UART1SendString ( Info02 ) ;
    ResetOutputModemLine ( RTSControlUARTCode ) ;
  } /* if */ ;
  if ( ( Ch == 'c' ) || ( Ch == 'C' ) )
  {
    UART1SendString ( Info03 ) ;
    SetOutputModemLine ( DTRControlUARTCode ) ;
  } /* if */ ;
  if ( ( Ch == 'd' ) || ( Ch == 'D' ) )
  {
    UART1SendString ( Info04 ) ;
    ResetOutputModemLine ( DTRControlUARTCode ) ;
  } /* if */ ;
  if ( Ch == '!' )
    UART1SendString ( Hello2 ) ;
  if ( Ch == '?' )
  {
    UART1SendString ( Prompt ) ;
    ModemStatus = GetOutputModemLine ( ) ;
    if ( ModemStatus & RTSControlUARTCode )
      UART1SendString ( RTSTxt ) ;
    if ( ModemStatus & DTRControlUARTCode )
      UART1SendString ( DTRTxt ) ;
    UART1Send ( 0x0D ) ;
    UART1Send ( 0x0A ) ;
  } /* if */ ;
} /* ProcessChar */


int main ( void )
{
  /*-------------------------------------------------------------------------*/
  SysInit ( ) ;
  HardwareInit ( )  ;
  SoftwareInit ( ) ;
  UART1HardwInit( FOSC , N81Mode , 9600 ) ;
  HelloMessage ( ) ;
  for ( ; ; )
  {
    if ( UART1DataPresent ( ) )
      ProcessChar ( UART1GetData ( ) ) ;
  } /* loop */ ;
} /* main */



